#define XERR
#include "simulator.ih"

Simulator::Simulator()
{
    imsg.off();
    setAnalysisSource();        // maybe one analysis (-o) or more
}
